@@ -20,6 +20,7 @@
 #include "dms.h"
 #include "kstars.h"
 #include "kstarsdata.h"
+#include "ksnotification.h"
 #include "skymap.h"
 #include "skyobjects/skypoint.h"
 
@@ -106,7 +107,7 @@ void FocusDialog::validatePoint()
             message += '\n' + i18n("The Declination value must be between -90.0 and 90.0.");
         if (!message.isEmpty())
         {
-            KMessageBox::sorry(nullptr, message, i18n("Invalid Coordinate Data"));
+            KSNotification::sorry(message, i18n("Invalid Coordinate Data"));
             return;
         }
 
@@ -134,7 +135,7 @@ void FocusDialog::validatePoint()
                 message += '\n' + i18n("The Altitude value must be between -90.0 and 90.0.");
             if (!message.isEmpty())
             {
-                KMessageBox::sorry(nullptr, message, i18n("Invalid Coordinate Data"));
+                KSNotification::sorry(message, i18n("Invalid Coordinate Data"));
                 return;
             }
 
