@@ -64,6 +64,8 @@ class Message : public QObject
         void disconnected();
         void expired();
         void optionsChanged(QMap<int, bool> options);
+        // This is forward signal from INDI::CCD
+        void previewJPEGGenerated(const QString &previewJPEG, QJsonObject metadata);
 
         void resetPolarView();
 
@@ -96,6 +98,10 @@ class Message : public QObject
         // DSLR
         void requestDSLRInfo(const QString &cameraName);
 
+        // Dialogs
+        void sendDialog(const QJsonObject &message);
+        void processDialogResponse(const QJsonObject &payload);
+
     private slots:
 
         // Connection
