@@ -314,6 +314,8 @@ class CCD : public DeviceDecorator
     public slots:
         void FITSViewerDestroyed();
         void StreamWindowHidden();
+        // Blob manager
+        void setBLOBManager(const char *device, INDI::Property * prop);
 
     protected slots:
         void setWSBLOB(const QByteArray &message, const QString &extension);
@@ -331,6 +333,7 @@ class CCD : public DeviceDecorator
         void newVideoFrame(std::unique_ptr<QImage> &frame);
         void coolerToggled(bool enabled);
         void previewFITSGenerated(const QString &previewFITS);
+        void previewJPEGGenerated(const QString &previewJPEG, QJsonObject metadata);
         void ready();
 
     private:
