@@ -68,6 +68,10 @@ public:
         {
             return m_CanAbsMove;
         }
+        bool canRelMove() const
+        {
+            return m_CanRelMove;
+        }
         bool canAbort() const
         {
             return m_CanAbort;
@@ -80,12 +84,18 @@ public:
 
         double azimuthPosition() const;
         bool setAzimuthPosition(double position);
+        bool setRelativePosition(double position);
 
 
         bool hasShutter() const
         {
             return m_HasShutter;
         }
+
+        // slaving
+        bool isAutoSync();
+        bool setAutoSync(bool activate);
+
         Status status() const
         {
             return m_Status;
@@ -105,6 +115,7 @@ public slots:
         void newStatus(Status status);
         void newParkStatus(ParkStatus status);
         void newShutterStatus(ShutterStatus status);
+        void newAutoSyncStatus(bool enabled);
         void azimuthPositionChanged(double Az);
         void ready();
 
@@ -113,6 +124,7 @@ public slots:
         ShutterStatus m_ShutterStatus { SHUTTER_UNKNOWN };
         Status m_Status { DOME_IDLE };
         bool m_CanAbsMove { false };
+        bool m_CanRelMove { false };
         bool m_CanPark { false };
         bool m_CanAbort { false };
         bool m_HasShutter { false };
