@@ -34,7 +34,7 @@
 SolarSystemComposite::SolarSystemComposite(SkyComposite *parent) : SkyComposite(parent)
 {
     emitProgressText(i18n("Loading solar system"));
-    m_Earth = new KSPlanet(I18N_NOOP("Earth"), QString(), QColor("white"), 12756.28 /*diameter in km*/);
+    m_Earth = new KSPlanet(i18n("Earth"), QString(), QColor("white"), 12756.28 /*diameter in km*/);
     m_Sun                           = new KSSun();
     SolarSystemSingleComponent *sun = new SolarSystemSingleComponent(this, m_Sun, Options::showSun);
     addComponent(sun, 2);
